pub struct ScrollTreeNode {
pub parent: Option<ScrollTreeNodeId>,
pub children: Vec<ScrollTreeNodeId>,
pub webrender_id: Option<SpatialId>,
pub info: SpatialTreeNodeInfo,
/* private fields */
}Expand description
A node in a tree of scroll nodes. This may either be a scrollable node which responds to scroll events or a non-scrollable one.
Fields
parent: Option<ScrollTreeNodeId>The index of the parent of this node in the tree. If this is None then this is the root node.
children: Vec<ScrollTreeNodeId>The children of this ScrollTreeNode.
webrender_id: Option<SpatialId>The WebRender id, which is filled in when this tree is serialiezd into a WebRender display list.
info: SpatialTreeNodeInfoSpecific information about this node, depending on whether it is a scroll node or a reference frame.
Implementations
Sourceimpl ScrollTreeNode
impl ScrollTreeNode
Sourcepub fn webrender_id(&self) -> SpatialId
pub fn webrender_id(&self) -> SpatialId
Get the WebRender SpatialId for the given [ScrollNodeId]. This will
panic if [ScrollTree::build_display_list] has not been called yet.
Sourcepub fn external_id(&self) -> Option<ExternalScrollId>
pub fn external_id(&self) -> Option<ExternalScrollId>
Get the external id of this node.
Sourcepub fn offset(&self) -> Option<LayoutVector2D>
pub fn offset(&self) -> Option<LayoutVector2D>
Get the offset id of this node if it applies.
pub fn debug_print(&self, print_tree: &mut PrintTree, node_index: usize)