Module rendering_context

Module rendering_context 

Structs

OffscreenRenderingContext
SoftwareRenderingContext
A software rendering context that uses a software OpenGL implementation to render Servo. This will generally have bad performance, but can be used in situations where it is more convenient to have consistent, but slower display output.
WindowRenderingContext
A RenderingContext that uses the surfman library to render to a raw-window-handle identified window. surfman will attempt to create an OpenGL context and surface for this window. This is a simple implementation of the RenderingContext trait, but by default it paints to the entire window surface.

Enums

Error
Various errors that methods can produce.

Traits

RenderingContext
The RenderingContext trait defines a set of methods for managing an OpenGL or GLES rendering context. Implementors of this trait are responsible for handling the creation, management, and destruction of the rendering context and its associated resources.