pub struct PaintProxy {
pub sender: Sender<Result<PaintMessage, IpcError>>,
pub cross_process_paint_api: CrossProcessPaintApi,
pub event_loop_waker: Box<dyn EventLoopWaker>,
}Expand description
Sends messages to Paint.
Fields
sender: Sender<Result<PaintMessage, IpcError>>cross_process_paint_api: CrossProcessPaintApiAccess to Self::sender that is possible to send across an IPC
channel. These messages are routed via the router thread to
Self::sender.
event_loop_waker: Box<dyn EventLoopWaker>Implementations
Sourceimpl PaintProxy
impl PaintProxy
pub fn send(&self, msg: PaintMessage)
Sourcepub fn route_msg(&self, msg: Result<PaintMessage, IpcError>)
pub fn route_msg(&self, msg: Result<PaintMessage, IpcError>)
Helper method to route a deserialized IPC message to the receiver.
This method is a temporary solution, and will be removed when migrating
to GenericChannel.