pub struct ViewportDescription {
pub initial_scale: Scale<f32, CSSPixel, DeviceIndependentPixel>,
pub minimum_scale: Scale<f32, CSSPixel, DeviceIndependentPixel>,
pub maximum_scale: Scale<f32, CSSPixel, DeviceIndependentPixel>,
pub user_scalable: UserScalable,
}Expand description
A set of viewport descriptors:
Fields
initial_scale: Scale<f32, CSSPixel, DeviceIndependentPixel>https://developer.mozilla.org/en-US/docs/Web/HTML/Viewport_meta_tag#initial-scale the zoom level when the page is first loaded
minimum_scale: Scale<f32, CSSPixel, DeviceIndependentPixel>The minimum page zoom that is allowed on this viewport’s page. https://developer.mozilla.org/en-US/docs/Web/HTML/Viewport_meta_tag#minimum_scale
maximum_scale: Scale<f32, CSSPixel, DeviceIndependentPixel>The maximum page zoom that is allowed on this viewport’s page. https://developer.mozilla.org/en-US/docs/Web/HTML/Viewport_meta_tag#maximum_scale
user_scalable: UserScalablehttps://developer.mozilla.org/en-US/docs/Web/HTML/Viewport_meta_tag#user_scalable whether zoom in and zoom out actions are allowed on the page
Implementations
Sourceimpl ViewportDescription
impl ViewportDescription
Sourcepub fn clamp_zoom(&self, zoom: f32) -> f32
pub fn clamp_zoom(&self, zoom: f32) -> f32
Constrains a zoom value within the allowed scale range